==> kadu_0.5.0.orig.tar.gz: pcspeaker/translations/pcspeaker_it.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>On message play</source>
        <translation>Quando nuovo messagio arriva suona</translation>
    </message>
    <message>
        <source>On chat play</source>
        <translation>Quando nuova chat comincia suona</translation>
    </message>
    <message>
        <source>On nofify play</source>
        <translation>Quando contatto cambia status suona</translation>
    </message>
    <message>
        <source>Put the played sounds separate by space, _ for pause, eg. D2 C1# G0</source>
        <translation>Scriva i toni separato con suoi lungo, per pausa scrivo _ . Per esempio: D2/1 C1#/4 _/2 H0#/3</translation>
    </message>
    <message>
        <source>Speaker volume</source>
        <translation>Volume</translation>
    </message>
    <message>
        <source>Test1</source>
        <translation>Test</translation>
    </message>
    <message>
        <source>Test2</source>
        <translation>Test</translation>
    </message>
    <message>
        <source>Test3</source>
        <translation>Test</translation>
    </message>
    <message>
        <source>Play sounds on</source>
        <translation type="obsolete">Suona quando</translation>
    </message>
    <message>
        <source>New message</source>
        <translation type="obsolete">Nuovo messagio arriva</translation>
    </message>
    <message>
        <source>New chat</source>
        <translation type="obsolete">Nuova chat comincia</translation>
    </message>
    <message>
        <source>User&apos;s status change</source>
        <translation type="obsolete">Contatto sta cambiato status</translation>
    </message>
    <message>
        <source>Connection Error</source>
        <translation type="obsolete">Errore conessione</translation>
    </message>
    <message>
        <source>Other message</source>
        <translation type="obsolete">Altro messagio arriva</translation>
    </message>
    <message>
        <source>Sounds</source>
        <translation>Suoni</translation>
    </message>
    <message>
        <source>On connection error play</source>
        <translation>Quando errore concessione accade suona</translation>
    </message>
    <message>
        <source>Test4</source>
        <translation>Test</translation>
    </message>
    <message>
        <source>On other messages play</source>
        <translation>Quando altro messagio arriva suona</translation>
    </message>
    <message>
        <source>Test5</source>
        <translation>Test</translation>
    </message>
    <message>
        <source>Please select events you want to be notified on using Notify tab in Configuration window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PC Speaker</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> kadu_0.6.0.2.orig.tar.gz: pcspeaker/translations/pcspeaker_it.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>On message play</source>
        <translation>Quando nuovo messagio arriva suona</translation>
    </message>
    <message>
        <source>On chat play</source>
        <translation>Quando nuova chat comincia suona</translation>
    </message>
    <message>
        <source>On nofify play</source>
        <translation>Quando contatto cambia status suona</translation>
    </message>
    <message>
        <source>Put the played sounds separate by space, _ for pause, eg. D2 C1# G0</source>
        <translation>Scriva i toni separato con suoi lungo, per pausa scrivo _ . Per esempio: D2/1 C1#/4 _/2 H0#/3</translation>
    </message>
    <message>
        <source>Speaker volume</source>
        <translation>Volume</translation>
    </message>
    <message>
        <source>Test1</source>
        <translation>Test</translation>
    </message>
    <message>
        <source>Test2</source>
        <translation>Test</translation>
    </message>
    <message>
        <source>Test3</source>
        <translation>Test</translation>
    </message>
    <message>
        <source>Play sounds on</source>
        <translation type="obsolete">Suona quando</translation>
    </message>
    <message>
        <source>New message</source>
        <translation type="obsolete">Nuovo messagio arriva</translation>
    </message>
    <message>
        <source>New chat</source>
        <translation type="obsolete">Nuova chat comincia</translation>
    </message>
    <message>
        <source>User&apos;s status change</source>
        <translation type="obsolete">Contatto sta cambiato status</translation>
    </message>
    <message>
        <source>Connection Error</source>
        <translation type="obsolete">Errore conessione</translation>
    </message>
    <message>
        <source>Other message</source>
        <translation type="obsolete">Altro messagio arriva</translation>
    </message>
    <message>
        <source>Sounds</source>
        <translation>Suoni</translation>
    </message>
    <message>
        <source>On connection error play</source>
        <translation>Quando errore concessione accade suona</translation>
    </message>
    <message>
        <source>Test4</source>
        <translation>Test</translation>
    </message>
    <message>
        <source>On other messages play</source>
        <translation>Quando altro messagio arriva suona</translation>
    </message>
    <message>
        <source>Test5</source>
        <translation>Test</translation>
    </message>
    <message>
        <source>Please select events you want to be notified on using Notify tab in Configuration window.</source>
        <translation>Selezione eventi per notificare sulla carta Generale.</translation>
    </message>
    <message>
        <source>PC Speaker</source>
        <translation>PC Speaker</translation>
    </message>
</context>
</TS>
